// GLSL fragment shader for terrain texturing by Peter Alexay, 2006
// Input:
// - the coverage factors are in coverage.rgb
// - the terrain's diffuse, shaded color is in gl_Color.rgb
// - the texture units for the coverage factors are tu0,tu1,tu2
// - the texture unit for the caustics texture is in tu3
// - the texture coordinates are in gl_TexCoord[0..2].st
// - the weight for terrain texture is in textureweight
// - the weight (flag) for caustics is in causticsweight

uniform sampler2D tu0,tu1,tu2,tu3;
uniform float causticsweight;
uniform float textureweight;
varying vec4 coverage;
varying float fogValue;

void main()
{
  vec4 texel;
  vec4 causttexel;
  vec4 resultColor;
  
  texel=texture2D(tu0,gl_TexCoord[0].st)*coverage.r +
        texture2D(tu1,gl_TexCoord[1].st)*coverage.g +
        texture2D(tu2,gl_TexCoord[2].st)*coverage.b;
  causttexel=texture2D(tu3,gl_TexCoord[3].st);
  
  //make caustics more blue-ish
  causttexel.r=causttexel.r/2.0;
  causttexel.g=causttexel.g/2.0;

  resultColor.rgb=texel.rgb*gl_Color.rgb*textureweight+causttexel.rgb*causticsweight;
  resultColor.a=1.0;
  
  gl_FragColor=mix(vec4(gl_Fog.color),resultColor,fogValue);
}
